==> spec-version-maven-plugin-1.5-sources.jar: org/glassfish/spec/maven/SetPropertiesMojo.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013-2018 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://oss.oracle.com/licenses/CDDL+GPL-1.1
 * or LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.spec.maven;

import java.util.Iterator;
import java.util.Map.Entry;
import java.util.Properties;
import org.apache.maven.plugin.AbstractMojo;
import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;
import org.apache.maven.plugins.annotations.LifecyclePhase;
import org.apache.maven.plugins.annotations.Mojo;
import org.apache.maven.plugins.annotations.Parameter;
import org.apache.maven.project.MavenProject;
import org.glassfish.spec.Artifact;
import org.glassfish.spec.Spec;

/**
 * Generate spec properties.
 * @author Romain Grecourt
 */
@Mojo(name = "set-spec-properties",
      requiresProject = true,
      defaultPhase = LifecyclePhase.VALIDATE)
public final class SetPropertiesMojo extends AbstractMojo {

    /**
     * The maven project.
     */
    @Parameter(defaultValue = "${project}", required = true, readonly = true)
    private MavenProject project;

    /**
     * The spec.
     */
    @Parameter(property = "spec", required = true)
    private Spec spec;

    @Override
    public void execute() throws MojoExecutionException, MojoFailureException {
        spec.setArtifact(new Artifact(
                project.getGroupId(),
                project.getArtifactId(),
                project.getVersion()));

        Properties specProps = spec.getMetadata().getProperties();

        getLog().info("");
        getLog().info("-- spec properties --");
        Iterator<Entry<Object, Object>> it = specProps.entrySet().iterator();
        while (it.hasNext()) {
            Entry<Object, Object> e =  it.next();
            getLog().info(e.getKey() + " = " + e.getValue());
        }
        getLog().info("");

        project.getProperties().putAll(specProps);
    }
}

==> spec-version-maven-plugin-2.1-sources.jar: org/glassfish/spec/maven/SetPropertiesMojo.java <==
/*
 * Copyright (c) 2013, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package org.glassfish.spec.maven;

import java.util.Iterator;
import java.util.Map.Entry;
import java.util.Properties;
import org.apache.maven.plugin.AbstractMojo;
import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;
import org.apache.maven.plugins.annotations.LifecyclePhase;
import org.apache.maven.plugins.annotations.Mojo;
import org.apache.maven.plugins.annotations.Parameter;
import org.apache.maven.project.MavenProject;
import org.glassfish.spec.Artifact;
import org.glassfish.spec.Spec;

/**
 * Generate spec properties.
 * @author Romain Grecourt
 */
@Mojo(name = "set-spec-properties",
      requiresProject = true,
      defaultPhase = LifecyclePhase.VALIDATE)
public final class SetPropertiesMojo extends AbstractMojo {

    /**
     * The maven project.
     */
    @Parameter(defaultValue = "${project}", required = true, readonly = true)
    private MavenProject project;

    /**
     * Mode. Allowed values are "javaee", "jakarta"
     */
    @Parameter(property = "specMode", defaultValue = "jakarta")
    private String specMode;

    /**
     * The spec.
     */
    @Parameter(property = "spec", required = true)
    private Spec spec;

    @Override
    public void execute() throws MojoExecutionException, MojoFailureException {
        spec.setSpecMode(specMode);
        spec.setArtifact(new Artifact(
                project.getGroupId(),
                project.getArtifactId(),
                project.getVersion()));
        Properties specProps = spec.getMetadata().getProperties();

        getLog().info("");
        getLog().info("-- spec properties --");
        Iterator<Entry<Object, Object>> it = specProps.entrySet().iterator();
        while (it.hasNext()) {
            Entry<Object, Object> e =  it.next();
            getLog().info(e.getKey() + " = " + e.getValue());
        }
        getLog().info("");

        project.getProperties().putAll(specProps);
    }
}
